package betterquesting.storage;

import betterquesting.api.properties.IPropertyContainer;
import betterquesting.api.properties.IPropertyType;
import betterquesting.api2.storage.INBTSaveLoad;
import java.util.ArrayList;
import java.util.List;
import net.minecraft.nbt.NBTBase;
import net.minecraft.nbt.NBTTagCompound;
import net.minecraft.util.ResourceLocation;

/* loaded from: betterquesting_storage.jar:betterquesting/storage/PropertyContainer.class */
public class PropertyContainer implements IPropertyContainer, INBTSaveLoad<NBTTagCompound> {
    private final NBTTagCompound nbtInfo = new NBTTagCompound();

    /* JADX WARN: Multi-variable type inference failed */
    public <T> T getProperty(IPropertyType<T> iPropertyType) {
        if (iPropertyType == null) {
            return null;
        }
        return (T) getProperty(iPropertyType, iPropertyType.getDefault());
    }

    public <T> T getProperty(IPropertyType<T> iPropertyType, T t) {
        if (iPropertyType == null) {
            return t;
        }
        synchronized (this.nbtInfo) {
            NBTTagCompound domain = getDomain(iPropertyType.getKey());
            if (!domain.func_74764_b(iPropertyType.getKey().func_110623_a())) {
                return t;
            }
            return (T) iPropertyType.readValue(domain.func_74781_a(iPropertyType.getKey().func_110623_a()));
        }
    }

    public boolean hasProperty(IPropertyType<?> prop) {
        boolean func_74764_b;
        if (prop == null) {
            return false;
        }
        synchronized (this.nbtInfo) {
            func_74764_b = getDomain(prop.getKey()).func_74764_b(prop.getKey().func_110623_a());
        }
        return func_74764_b;
    }

    public void removeProperty(IPropertyType<?> prop) {
        if (prop == null) {
            return;
        }
        synchronized (this.nbtInfo) {
            NBTTagCompound jProp = getDomain(prop.getKey());
            if (jProp.func_74764_b(prop.getKey().func_110623_a())) {
                jProp.func_82580_o(prop.getKey().func_110623_a());
                if (jProp.func_82582_d()) {
                    this.nbtInfo.func_82580_o(prop.getKey().func_110624_b());
                }
            }
        }
    }

    public <T> void setProperty(IPropertyType<T> prop, T value) {
        if (prop == null || value == null) {
            return;
        }
        synchronized (this.nbtInfo) {
            NBTTagCompound dom = getDomain(prop.getKey());
            dom.func_74782_a(prop.getKey().func_110623_a(), prop.writeValue(value));
            this.nbtInfo.func_74782_a(prop.getKey().func_110624_b(), dom);
        }
    }

    public void removeAllProps() {
        synchronized (this.nbtInfo) {
            List<String> keys = new ArrayList<>(this.nbtInfo.func_150296_c());
            for (String key : keys) {
                this.nbtInfo.func_82580_o(key);
            }
        }
    }

    public NBTTagCompound writeToNBT(NBTTagCompound nbt) {
        synchronized (this.nbtInfo) {
            merge(nbt, this.nbtInfo);
        }
        return nbt;
    }

    @Override // 
    public void readFromNBT(NBTTagCompound nbt) {
        synchronized (this.nbtInfo) {
            for (String key : this.nbtInfo.func_150296_c()) {
                this.nbtInfo.func_82580_o(key);
            }
            merge(this.nbtInfo, nbt);
        }
    }

    private NBTTagCompound getDomain(ResourceLocation res) {
        return this.nbtInfo.func_74775_l(res.func_110624_b());
    }

    private void merge(NBTTagCompound parent, NBTTagCompound other) {
        for (String s : other.func_150296_c()) {
            NBTBase nbtbase = other.func_74781_a(s);
            if (nbtbase.func_74732_a() == 10) {
                if (parent.func_150297_b(s, 10)) {
                    NBTTagCompound nbttagcompound = parent.func_74775_l(s);
                    merge(nbttagcompound, (NBTTagCompound) nbtbase);
                } else {
                    parent.func_74782_a(s, nbtbase.func_74737_b());
                }
            } else {
                parent.func_74782_a(s, nbtbase.func_74737_b());
            }
        }
    }
}
